# Change Log

## 0.1.2

### Patch Changes

- [#32](https://github.com/withastro/houston-vscode/pull/32) [`e39cb05`](https://github.com/withastro/houston-vscode/commit/e39cb055609ae92a87566bdbd940058420683145) Thanks [@natemoo-re](https://github.com/natemoo-re)! - Optimize preview image

## 0.1.1

### Patch Changes

- [#24](https://github.com/withastro/houston-vscode/pull/24) [`a959330`](https://github.com/withastro/houston-vscode/commit/a959330f5bf95e560211806ab61b3d0f9ed4a108) Thanks [@VoxelMC](https://github.com/VoxelMC)! - Increase contrast of text highlight and fix visibility of whitespace markers

- [#23](https://github.com/withastro/houston-vscode/pull/23) [`d297233`](https://github.com/withastro/houston-vscode/commit/d297233be95e3f8fdecc22e4ffa92bb0e7265592) Thanks [@VoxelMC](https://github.com/VoxelMC)! - Reduce scrollbar opacity to show minimap colours

## v0.1.0

- Improve comment contrast
- Adjust comment transparency to improve behavior in diff view

## v0.0.9

- Fix error widget colors

## v0.0.8

- Make badge colors neutral

## v0.0.7

- Improve Status Bar colors

## v0.0.6

- Improve Panel theming, borders
- Set minimum VS Code version to 1.71.0

## v0.0.5

- Improve styles, centering and scaling of character

## v0.0.3

- Tweaks to ANSI colors, sidebar colors

## v0.0.1

- Initial release
